@@ -23,6 +23,7 @@ class InsertRequest():
     '''
     attributeId = 0
     entry = {}
+    attributeId = 0
 
 
 class UpdateRequest(InsertRequest):
@@ -288,6 +289,9 @@ class EntryService(ApiMethods):
             if (field is None):
                 continue
             request.entry[field.get('column')] = body.entry[field.get('displayName')] 
+
+        if 'id' in body.entry:
+            request.entry['id'] = body.entry['id']            
         
         return request            
 
@@ -303,10 +307,20 @@ class EntryService(ApiMethods):
         Returns
         -------
             The updated entry's indentifier.
-        '''        
-        request = body=self.__convertToInputRequest(body)
+        '''   
+        
+        if body is None:
+            raise Exception("Invalid body")
 
-        return self.update(body=request)
+        if body.entry is None:
+            raise Exception("Invalid entry")            
+
+        if "id" not in body.entry:
+            raise Exception("Missing entry id. e.g: entry['id'] = `entry id`")
+
+        body = self.__convertToInputRequest(body)
+
+        return self.update(body=body)
 
     def create(self, body: InsertRequest) -> str:
         '''
@@ -321,6 +335,7 @@ class EntryService(ApiMethods):
         -------
             The new entry's indentifier.
         '''
+        print("creating")
         body.entry['id'] = str(uuid.uuid1())
         api_url = '/api/services/app/Entry/Create'
         response =  self.post_data(url=api_url, body=body)
